@@ -13,6 +13,7 @@ from .entity import (
     FileTemplateVariables,
     FilesTemplateVariables,
     NodeInventory,
+    ProxyInfo,
     RandomTemplateVariables,
     RecoverSetting,
     SearchItem,
@@ -36,6 +37,7 @@ from .dto import (
     FileTemplateVariablesDTO,
     FilesTemplateVariablesDTO,
     NodeInventoryDTO,
+    ProxyInfoDTO,
     RandomTemplateVariablesDTO,
     RecoverSettingDTO,
     SearchItemDTO,
@@ -442,6 +444,7 @@ class SearchRequestAssembler(Assembler):
         return SearchRequest(
             keyword = UStr(dto.keyword),
             limit = UInt(dto.limit),
+            timeout = UInt(dto.timeout),
             request_id = None if dto.request_id is None else UStr(dto.request_id),
             others = None if dto.others is None else UDict(dto.others)
         )
@@ -449,6 +452,7 @@ class SearchRequestAssembler(Assembler):
         return SearchRequestDTO(
             keyword = x.keyword.get_value(),
             limit = x.limit.get_value(),
+            timeout = x.timeout.get_value(),
             request_id = None if x.request_id is None else x.request_id.get_value(),
             others = None if x.others is None else x.others.get_value()
         )
@@ -485,7 +489,8 @@ class SearchItemAssembler(Assembler):
             response = None if dto.response is None else search_response_assembler.to_entity(dto.response),
             entry_time = None if dto.entry_time is None else UDate(dto.entry_time),
             exit_time = None if dto.exit_time is None else UDate(dto.exit_time),
-            create_time = None if dto.create_time is None else UDate(dto.create_time)
+            create_time = None if dto.create_time is None else UDate(dto.create_time),
+            failure_times = UInt(dto.failure_times)
         )
     def to_dto(self, x:SearchItem):
         return SearchItemDTO(
@@ -496,6 +501,26 @@ class SearchItemAssembler(Assembler):
             response = None if x.response is None else search_response_assembler.to_dto(x.response),
             entry_time = None if x.entry_time is None else x.entry_time.get_value(),
             exit_time = None if x.exit_time is None else x.exit_time.get_value(),
-            create_time = None if x.create_time is None else x.create_time.get_value()
+            create_time = None if x.create_time is None else x.create_time.get_value(),
+            failure_times = x.failure_times.get_value()
         )
 search_item_assembler=SearchItemAssembler()
+
+
+
+class ProxyInfoAssembler(Assembler):
+    def to_entity(self, dto: ProxyInfoDTO):
+        return ProxyInfo(
+            ip = UStr(dto.ip),
+            port = UInt(dto.port),
+            protocol = UStr(dto.protocol),
+            auth = None if dto.auth is None else UDict(dto.auth)
+        )
+    def to_dto(self, x:ProxyInfo):
+        return ProxyInfoDTO(
+            ip = x.ip.get_value(),
+            port = x.port.get_value(),
+            protocol = x.protocol.get_value(),
+            auth = None if x.auth is None else x.auth.get_value()
+        )
+proxy_info_assembler=ProxyInfoAssembler()
