@@ -13,6 +13,7 @@ from .entity import (
     FileTemplateVariables,
     FilesTemplateVariables,
     NodeInventory,
+    ProxyInfo,
     RandomTemplateVariables,
     RecoverSetting,
     SearchItem,
@@ -36,6 +37,7 @@ from .do import (
     FileTemplateVariablesDO,
     FilesTemplateVariablesDO,
     NodeInventoryDO,
+    ProxyInfoDO,
     RandomTemplateVariablesDO,
     RecoverSettingDO,
     SearchItemDO,
@@ -442,6 +444,7 @@ class SearchRequestConverter(Converter):
         return SearchRequest(
             keyword = UStr(do.keyword),
             limit = UInt(do.limit),
+            timeout = UInt(do.timeout),
             request_id = None if do.request_id is None else UStr(do.request_id),
             others = None if do.others is None else UDict(do.others)
         )
@@ -449,6 +452,7 @@ class SearchRequestConverter(Converter):
         return SearchRequestDO(
             keyword = x.keyword.get_value(),
             limit = x.limit.get_value(),
+            timeout = x.timeout.get_value(),
             request_id = None if x.request_id is None else x.request_id.get_value(),
             others = None if x.others is None else x.others.get_value()
         )
@@ -485,7 +489,8 @@ class SearchItemConverter(Converter):
             response = None if do.response is None else search_response_converter.to_entity(do.response),
             entry_time = None if do.entry_time is None else UDate(do.entry_time),
             exit_time = None if do.exit_time is None else UDate(do.exit_time),
-            create_time = None if do.create_time is None else UDate(do.create_time)
+            create_time = None if do.create_time is None else UDate(do.create_time),
+            failure_times = UInt(do.failure_times)
         )
     def to_do(self, x:SearchItem):
         return SearchItemDO(
@@ -496,6 +501,26 @@ class SearchItemConverter(Converter):
             response = None if x.response is None else search_response_converter.to_do(x.response),
             entry_time = None if x.entry_time is None else x.entry_time.get_value(),
             exit_time = None if x.exit_time is None else x.exit_time.get_value(),
-            create_time = None if x.create_time is None else x.create_time.get_value()
+            create_time = None if x.create_time is None else x.create_time.get_value(),
+            failure_times = x.failure_times.get_value()
         )
 search_item_converter=SearchItemConverter()
+
+
+
+class ProxyInfoConverter(Converter):
+    def to_entity(self, do: ProxyInfoDO):
+        return ProxyInfo(
+            ip = UStr(do.ip),
+            port = UInt(do.port),
+            protocol = UStr(do.protocol),
+            auth = None if do.auth is None else UDict(do.auth)
+        )
+    def to_do(self, x:ProxyInfo):
+        return ProxyInfoDO(
+            ip = x.ip.get_value(),
+            port = x.port.get_value(),
+            protocol = x.protocol.get_value(),
+            auth = None if x.auth is None else x.auth.get_value()
+        )
+proxy_info_converter=ProxyInfoConverter()
