@@ -170,6 +170,7 @@ class RecoverSettingDTO(BaseModel):
 class SearchRequestDTO(BaseModel):
     keyword: str
     limit: int = 5
+    timeout: int = '300'
     request_id: Optional[str] = None
     others: Optional[dict] = None
 
@@ -191,4 +192,13 @@ class SearchItemDTO(BaseModel):
     response: Optional[SearchResponseDTO] = None
     entry_time: Optional[datetime.datetime] = None
     exit_time: Optional[datetime.datetime] = None
-    create_time: Optional[datetime.datetime] = None
\ No newline at end of file
+    create_time: Optional[datetime.datetime] = None
+    failure_times: int = 0
+
+
+
+class ProxyInfoDTO(BaseModel):
+    ip: str
+    port: int
+    protocol: str
+    auth: Optional[dict] = None
\ No newline at end of file
