@@ -433,6 +433,7 @@ class SearchRequest(Entity):
         self,
         keyword: UStr,
         limit: UInt = 5,
+        timeout: UInt = '300',
         request_id: Optional[UStr] = None,
         others: Optional[UDict] = None,
         **kwargs
@@ -444,6 +445,7 @@ class SearchRequest(Entity):
         super().__init__(**all_args)
         self.keyword = keyword
         self.limit = limit
+        self.timeout = timeout
         self.request_id = request_id
         self.others = others
 
@@ -481,6 +483,7 @@ class SearchItem(Entity):
         entry_time: Optional[UDate] = None,
         exit_time: Optional[UDate] = None,
         create_time: Optional[UDate] = None,
+        failure_times: UInt = 0,
         **kwargs
     ) -> None:
         all_args=locals()
@@ -495,4 +498,26 @@ class SearchItem(Entity):
         self.response = response
         self.entry_time = entry_time
         self.exit_time = exit_time
-        self.create_time = create_time
\ No newline at end of file
+        self.create_time = create_time
+        self.failure_times = failure_times
+
+
+
+class ProxyInfo(Entity):
+    def __init__(
+        self,
+        ip: UStr,
+        port: UInt,
+        protocol: UStr,
+        auth: Optional[UDict] = None,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.ip = ip
+        self.port = port
+        self.protocol = protocol
+        self.auth = auth
\ No newline at end of file
